@@ -41,6 +41,14 @@ MIDDLEWARE_CLASSES = [
 
 ROOT_URLCONF = 'tests.urls'
 
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'APP_DIRS': True,
+        'OPTIONS': {},
+    },
+]
+
 STATIC_ROOT = os.path.join(BASE_DIR, 'tests', 'static')
 
 STATIC_URL = '/static/'
